==> haskell-wide-word-0.1.7.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wide-word.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wide-word
version:              0.1.7.1
visibility:           public
id:                   wide-word-0.1.7.1-F8ebwR38tKUCM2zKjPYZ7m
key:                  wide-word-0.1.7.1-F8ebwR38tKUCM2zKjPYZ7m
license:              BSD-2-Clause
copyright:
    Copyright (c) 2017 Erik de Castro Lopo <erikd@mega-nerd.com>

maintainer:           erikd@mega-nerd.com
author:               Erik de Castro Lopo
stability:            provisional
homepage:             https://github.com/erikd/wide-word
synopsis:
    Data types for large but fixed width signed and unsigned integers

description:
    A library to provide data types for large (ie > 64 bits) but fixed width signed
    and unsigned integers with the usual typeclass instances to allow them to be used
    interchangeably with `Word64`.

    The types and operations are coded to be as fast as possible using strictness
    annotations, `INLINEABLE` pragmas and unboxed values and operations where
    appropriate.

category:             Data
abi:                  49a453173d2d7e675575ec6b9a5fa858
exposed:              True
exposed-modules:
    Data.WideWord Data.WideWord.Int128 Data.WideWord.Word128
    Data.WideWord.Word256 Data.WideWord.Word64

hidden-modules:       Data.WideWord.Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wide-word-0.1.7.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wide-word-0.1.7.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wide-word-0.1.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wide-word
hs-libraries:         HSwide-word-0.1.7.1-F8ebwR38tKUCM2zKjPYZ7m
depends:
    base-4.17.2.1 binary-0.8.9.1 deepseq-1.4.8.0 ghc-prim-0.9.1
    hashable-1.4.4.0-C1fFIG7AZLC7j0jzLm97Uw
    primitive-0.9.1.0-8D3oUlMRcY7326zIYb2IW2

haddock-interfaces:   /usr/share/doc/haskell-wide-word/html/wide-word.haddock
haddock-html:         /usr/share/doc/haskell-wide-word/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wide-word-0.1.7.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wide-word.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wide-word
version:              0.1.7.1
visibility:           public
id:                   wide-word-0.1.7.1-GC9ppzEByd77S1VfXc9unQ
key:                  wide-word-0.1.7.1-GC9ppzEByd77S1VfXc9unQ
license:              BSD-2-Clause
copyright:
    Copyright (c) 2017 Erik de Castro Lopo <erikd@mega-nerd.com>

maintainer:           erikd@mega-nerd.com
author:               Erik de Castro Lopo
stability:            provisional
homepage:             https://github.com/erikd/wide-word
synopsis:
    Data types for large but fixed width signed and unsigned integers

description:
    A library to provide data types for large (ie > 64 bits) but fixed width signed
    and unsigned integers with the usual typeclass instances to allow them to be used
    interchangeably with `Word64`.

    The types and operations are coded to be as fast as possible using strictness
    annotations, `INLINEABLE` pragmas and unboxed values and operations where
    appropriate.

category:             Data
abi:                  5c1da4dbf0d2749bcbdd815853ce8813
exposed:              True
exposed-modules:
    Data.WideWord Data.WideWord.Int128 Data.WideWord.Word128
    Data.WideWord.Word256 Data.WideWord.Word64

hidden-modules:       Data.WideWord.Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wide-word-0.1.7.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wide-word-0.1.7.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wide-word-0.1.7.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wide-word
hs-libraries:         HSwide-word-0.1.7.1-GC9ppzEByd77S1VfXc9unQ
depends:
    base-4.17.2.1 binary-0.8.9.1 deepseq-1.4.8.0 ghc-prim-0.9.1
    hashable-1.4.4.0-C1fFIG7AZLC7j0jzLm97Uw
    primitive-0.9.1.0-8D3oUlMRcY7326zIYb2IW2

haddock-interfaces:   /usr/share/doc/haskell-wide-word/html/wide-word.haddock
haddock-html:         /usr/share/doc/haskell-wide-word/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
